@@ -36,7 +36,7 @@
 '''
 
 __docformat__ = 'restructuredtext'
-__version__ = '$Id: gdkpixbuf2.py 1939 2008-03-21 11:48:12Z Alex.Holkner $'
+__version__ = '$Id$'
 
 from ctypes import *
 
@@ -76,12 +76,11 @@ class GdkPixbuf2ImageDecoder(ImageDecoder):
 
     def _load(self, file, filename, load_func):
         data = file.read()
-        err = c_int()
         loader = gdkpixbuf.gdk_pixbuf_loader_new()
-        gdkpixbuf.gdk_pixbuf_loader_write(loader, data, len(data), byref(err))
-        result = load_func(loader)
-        if not gdkpixbuf.gdk_pixbuf_loader_close(loader, byref(err)):
+        gdkpixbuf.gdk_pixbuf_loader_write(loader, data, len(data), None)
+        if not gdkpixbuf.gdk_pixbuf_loader_close(loader, None):
             raise ImageDecodeException(filename)
+        result = load_func(loader)
         if not result:
             raise ImageDecodeException('Unable to load: %s' % filename)
         return result
@@ -92,7 +91,7 @@ class GdkPixbuf2ImageDecoder(ImageDecoder):
         height = gdkpixbuf.gdk_pixbuf_get_height(pixbuf)
         channels = gdkpixbuf.gdk_pixbuf_get_n_channels(pixbuf)
         rowstride = gdkpixbuf.gdk_pixbuf_get_rowstride(pixbuf)
-        has_alpha = gdkpixbuf.gdk_pixbuf_get_has_alpha(pixbuf)
+        #has_alpha = gdkpixbuf.gdk_pixbuf_get_has_alpha(pixbuf)
         pixels = gdkpixbuf.gdk_pixbuf_get_pixels(pixbuf)
 
         # Copy pixel data.
@@ -134,17 +133,33 @@ class GdkPixbuf2ImageDecoder(ImageDecoder):
         # Extract each image   
         for control_delay in delays:
             pixbuf = gdkpixbuf.gdk_pixbuf_animation_iter_get_pixbuf(iter)
+            # When attempting to load animated gifs with an alpha channel on
+            #  linux gdkpixbuf will normally return a null pixbuf for the final
+            #  frame resulting in a segfault:
+            #  http://code.google.com/p/pyglet/issues/detail?id=411
+            # Since it is unclear why exactly this happens, the workaround
+            #  below is to start again and extract that frame on its own.
+            if pixbuf == None:
+                file.seek(0)
+                anim = self._load(file, filename,
+                                gdkpixbuf.gdk_pixbuf_loader_get_animation)
+                temptime = GTimeVal(0, 0)
+                iter = gdkpixbuf.gdk_pixbuf_animation_get_iter(anim, byref(temptime))
+                gdkpixbuf.gdk_pixbuf_animation_iter_advance(iter, byref(time))
+                pixbuf = gdkpixbuf.gdk_pixbuf_animation_iter_get_pixbuf(iter)
             image = self._pixbuf_to_image(pixbuf)
             frames.append(AnimationFrame(image, control_delay))
 
+            gdk_delay = gdkpixbuf.gdk_pixbuf_animation_iter_get_delay_time(iter)
+
+            if gdk_delay == -1:
+                break
+
             gdk_delay = gdkpixbuf.gdk_pixbuf_animation_iter_get_delay_time(iter)
             gdk_delay *= 1000 # milliseconds to microseconds
             # Compare gdk_delay to control_delay for interest only.
             #print control_delay, gdk_delay / 1000000.
 
-            if gdk_delay == -1:
-                break
-
             us = time.tv_usec + gdk_delay
             time.tv_sec += us // 1000000
             time.tv_usec = us % 1000000
